@@ -31,8 +31,6 @@
 #' }
 #' @param corr.p Correlation between the exposure-specific confounder prevalences.
 #' @param alpha Significance level.
-#' @param dec Number of decimals in the printout.
-#' @param print A logical scalar. Should the results be printed?
 #'
 #' @return A list with elements:
 #' \item{obs.data}{The analysed 2 x 2 table from the observed data.}
@@ -70,9 +68,7 @@ probsens.irr.conf <- function(counts,
                                                "log-normal"),
                               parms = NULL),
                          corr.p = NULL,
-                         alpha = 0.05,
-                         dec = 4,
-                         print = TRUE){
+                         alpha = 0.05){
     if(reps < 1)
         stop(paste("Invalid argument: reps = ", reps))
     
@@ -419,38 +415,19 @@ probsens.irr.conf <- function(counts,
         rownames(tab) <- c("Cases", "Person-time")
     if (is.null(colnames(tab)))
         colnames(tab) <- c("Exposed", "Unexposed")
-    if (print) {
-        cat("Observed Data:",
-            "\n-------------------------",
-            "\n\n")
-        print(round(tab, dec))
-        cat("\n")
-    }
-    rmat <- data.frame(obs.irr, lci.obs.irr, uci.obs.irr)
+    rmat <- matrix(c(obs.irr, lci.obs.irr, uci.obs.irr), nrow = 1)
     rownames(rmat) <- " Observed Incidence Rate ratio:"
-    colnames(rmat) <- c("     ", paste(100 * (1 - alpha), "% conf.", 
-                                       sep = ""), "interval")
-    if (print) {
-        cat("Observed Measures:",
-            "\n-----------------------------------------------------\n\n")
-        print(round(rmat, dec))
-        cat("\n")
-    }
+    colnames(rmat) <- c(" ",
+                        paste(100 * (alpha/2), "%", sep = ""),
+                        paste(100 * (1 - alpha/2), "%", sep = ""))
     rmatc <- rbind(corr.irr, tot.irr)
     rownames(rmatc) <- c("           Incidence Rate Ratio -- systematic error:",
                          "Incidence Rate Ratio -- systematic and random error:")
     colnames(rmatc) <- c("Median", "2.5th percentile", "97.5th percentile")
-    if (print) {
-        print(round(rmatc, dec))
-        cat("\nBias Parameters:",
-            "\n----------------\n\n")
-        cat("p(Confounder+|Exposure+):", prev.exp[[1]], "(", prev.exp[[2]], ")",
-            "\np(Confounder+|Exposure-):", prev.nexp[[1]], "(", prev.nexp[[2]], ")",
-            "\nRisk(Confounder-Outcome):", risk[[1]], "(", risk[[2]], ")",
-            "\n")
-    }
-    invisible(list(obs.data = tab,
-                   obs.measures = rmat, 
-                   adj.measures = rmatc,
-                   sim.df = as.data.frame(draws[, -13])))
+    res <- list(obs.data = tab,
+                obs.measures = rmat, 
+                adj.measures = rmatc,
+                sim.df = as.data.frame(draws[, -13]))
+    class(res) <- c("episensr", "list")
+    res
 }
